@@ -2,6 +2,8 @@ package operator
 
 import (
 	"context"
+	"k8s.io/klog/v2"
+	"os"
 	"time"
 
 	"k8s.io/client-go/kubernetes"
@@ -10,6 +12,7 @@ import (
 	operatorclientinformers "github.com/openshift/cluster-kube-descheduler-operator/pkg/generated/informers/externalversions"
 	"github.com/openshift/cluster-kube-descheduler-operator/pkg/operator/operatorclient"
 	"github.com/openshift/library-go/pkg/controller/controllercmd"
+	"github.com/openshift/library-go/pkg/operator/loglevel"
 	"github.com/openshift/library-go/pkg/operator/v1helpers"
 )
 
@@ -33,7 +36,6 @@ func RunOperator(ctx context.Context, cc *controllercmd.ControllerContext) error
 		return err
 	}
 	operatorConfigInformers := operatorclientinformers.NewSharedInformerFactory(operatorConfigClient, 10*time.Minute)
-
 	deschedulerClient := &operatorclient.DeschedulerClient{
 		Ctx:            ctx,
 		SharedInformer: operatorConfigInformers.Kubedeschedulers().V1beta1().KubeDeschedulers().Informer(),
@@ -42,6 +44,7 @@ func RunOperator(ctx context.Context, cc *controllercmd.ControllerContext) error
 
 	targetConfigReconciler := NewTargetConfigReconciler(
 		ctx,
+		os.Getenv("IMAGE"),
 		operatorConfigClient.KubedeschedulersV1beta1(),
 		operatorConfigInformers.Kubedeschedulers().V1beta1().KubeDeschedulers(),
 		deschedulerClient,
@@ -49,9 +52,17 @@ func RunOperator(ctx context.Context, cc *controllercmd.ControllerContext) error
 		cc.EventRecorder,
 	)
 
+	logLevelController := loglevel.NewClusterOperatorLoggingController(deschedulerClient, cc.EventRecorder)
+
+	klog.Infof("Starting informers")
 	operatorConfigInformers.Start(ctx.Done())
 	kubeInformersForNamespaces.Start(ctx.Done())
-	targetConfigReconciler.Run(1, ctx.Done())
 
+	klog.Infof("Starting log level controller")
+	go logLevelController.Run(ctx, 1)
+	klog.Infof("Starting target config reconciler")
+	go targetConfigReconciler.Run(1, ctx.Done())
+
+	<-ctx.Done()
 	return nil
 }
